# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.1.0] - 2020-11-28
## Added
- added function `decode_bits`

## [1.0.1] - 2020-09-04
### Fixed
- fix wheel missing module

## [1.0.0] - 2020-09-04
### Added
- `encode()` & `decode()` accepting `bytes`, `bytearray` and list of `int`
- G. E. Thomas convention only

[Unreleased]: https://github.com/fphammerle/python-manchester-code/compare/v1.1.0...HEAD
[1.1.0]: https://github.com/fphammerle/python-manchester-code/compare/v1.0.1...v1.1.0
[1.0.1]: https://github.com/fphammerle/python-manchester-code/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/fphammerle/python-manchester-code/releases/tag/v1.0.0
